@@ -1,11 +1,8 @@
+import io
 from abc import ABCMeta
-from typing import TYPE_CHECKING, Any, Dict, Generic, Iterable, Optional, Tuple, TypeVar
-
-try:
-    from typing import Protocol
-except ImportError:
-    # Python 3.7 doesn't have Protocol
-    Protocol = object  # type: ignore[assignment]
+from collections.abc import Iterable
+from pprint import PrettyPrinter
+from typing import TYPE_CHECKING, Any, Generic, Optional, Protocol, TypeVar
 
 from ._utils import Omit
 
@@ -17,6 +14,9 @@ __all__ = 'DirtyEqualsMeta', 'DirtyEquals', 'AnyThing', 'IsOneOf'
 
 class DirtyEqualsMeta(ABCMeta):
     def __eq__(self, other: Any) -> bool:
+        if self is other:
+            return True
+
         # this is required as fancy things happen when creating generics which include equals checks, without it,
         # we get some recursive errors
         if self is DirtyEquals or other is Generic or other is Protocol:
@@ -64,7 +64,7 @@ class DirtyEquals(Generic[T], metaclass=DirtyEqualsMeta):
         self._other: Any = None
         self._was_equal: Optional[bool] = None
         self._repr_args: Iterable[Any] = repr_args
-        self._repr_kwargs: Dict[str, Any] = repr_kwargs
+        self._repr_kwargs: dict[str, Any] = repr_kwargs
 
     def equals(self, other: Any) -> bool:
         """
@@ -137,6 +137,26 @@ class DirtyEquals(Generic[T], metaclass=DirtyEqualsMeta):
             # else return something which explains what's going on.
             return self._repr_ne()
 
+    def _pprint_format(self, pprinter: PrettyPrinter, stream: io.StringIO, *args: Any, **kwargs: Any) -> None:
+        # pytest diffs use pprint to format objects, so we patch pprint to call this method
+        # for DirtyEquals objects. So this method needs to follow the same pattern as __repr__.
+        # We check that the protected _format method actually exists
+        # to be safe and to make linters happy.
+        if self._was_equal and hasattr(pprinter, '_format'):
+            pprinter._format(self._other, stream, *args, **kwargs)
+        else:
+            stream.write(repr(self))  # i.e. self._repr_ne() (for now)
+
+
+# Patch pprint to call _pprint_format for DirtyEquals objects
+# Check that the protected attribute _dispatch exists to be safe and to make linters happy.
+# The reason we modify _dispatch rather than _format
+# is that pytest sometimes uses a subclass of PrettyPrinter which overrides _format.
+if hasattr(PrettyPrinter, '_dispatch'):  # pragma: no branch
+    PrettyPrinter._dispatch[DirtyEquals.__repr__] = lambda pprinter, obj, *args, **kwargs: obj._pprint_format(
+        pprinter, *args, **kwargs
+    )
+
 
 InstanceOrType: 'TypeAlias' = 'Union[DirtyEquals[Any], DirtyEqualsMeta]'
 
@@ -229,7 +249,7 @@ class IsOneOf(DirtyEquals[Any]):
         assert [] == Contains(1) | IsOneOf([])
         ```
         """
-        self.expected_values: Tuple[Any, ...] = (expected_value,) + more_expected_values
+        self.expected_values: tuple[Any, ...] = (expected_value,) + more_expected_values
         super().__init__(*self.expected_values)
 
     def equals(self, other: Any) -> bool:
